@@ -21,4 +21,6 @@ pref("imagezoom.version", "0.0.0");
 pref("imagezoom.reversescrollzoom", false);
 pref("imagezoom.showViewMenu", true);
 pref("imagezoom.defaultGlobalZoom", "100");
-pref("imagezoom.scrollZoomMode", 0);
\ No newline at end of file
+pref("imagezoom.scrollZoomMode", 0);
+pref("imagezoom.autofitlargeimage", false);
+pref("imagezoom.showAutoFitInMenu", false);
\ No newline at end of file
